Basic Audio Signal Processing Library

Dependents:   unzen_sample_nucleo_f746 skeleton_unzen_nucleo_f746 ifmag_noise_canceller synthesizer_f746

オーディオ信号処理用のライブラリです。

mbed-dspのフィルタ群向けに作ったクラス・ラッパーのほか、以下のクラスを用意しています。

  • ヒステリシス
  • sin/cosオシレータ
  • リミッター

クラスは全て名前空間amakusaに含まれます。

Revision:
5:3d6cf4dbf458
Parent:
1:0a37bce4f985
Child:
6:ed10856c2305
--- a/firinterpolator.h	Thu Jan 26 03:42:05 2017 +0000
+++ b/firinterpolator.h	Fri Feb 10 13:24:30 2017 +0000
@@ -16,10 +16,10 @@
             * @brief Constructor
             * @param[in] taps Number of the elements in the coeffisients array. Or length of the impuls response. The taps must be integer multiple of L
             * @param[in] pCoeff Ponter to the coefficients array ( Impuls response ).
             * @param[in] blockSize Maximum number of the input samples to be given to run() method at onece. 
             * @param[in] L Up sampling ratio 
             */
-        FIRInterpolator(uint16_t taps, float32_t *pCoeff, uint32_t blockSize, uint8_t L);
+        FIRInterpolator(uint16_t taps, float32_t *pCoeff, uint32_t block_size, uint8_t L);
             /**
             * Destructor
             */
@@ -28,9 +28,9 @@
             * @brief Run the filter.
             * @param[in] pSrc Pointer to the source buffer to be filtered.
             * @param[out] pDst Pointer to the destination buffer to store the filtered signal. 
             * @param[in] blockSize Number of the sample to be filitered. If skipped or zero, blockSize is assmued the one passed to the constructor. 
             */
-        virtual void run( float32_t *pSrc, float32_t *pDst, uint32_t blockSize = 0 );
+        virtual void run( float32_t *pSrc, float32_t *pDst);
     private:
         arm_fir_interpolate_instance_f32 state;
     };
@@ -16,10 +16,10 @@
             * @param[in] taps Number of the elements in the coeffisients array. Or length of the impuls response. The taps must be integer multiple of L
             * @param[in] pCoeff Ponter to the coefficients array ( Impuls response ).
-            * @param[in] blockSize Maximum number of the input samples to be given to run() method at onece. 
+            * @param[in] block_size Maximum number of the input samples to be given to run() method at onece. 
             * @param[in] L Up sampling ratio 
             */
@@ -28,9 +28,9 @@
             * @param[in] pSrc Pointer to the source buffer to be filtered.
             * @param[out] pDst Pointer to the destination buffer to store the filtered signal. 
-            * @param[in] blockSize Number of the sample to be filitered. If skipped or zero, blockSize is assmued the one passed to the constructor. 
+            * @param[in] block_size Number of the sample to be filitered. If skipped or zero, block_size is assmued the one passed to the constructor. 
             */